<?php
/**
 * The template for displaying the header.
 *
 * @package Bloggo
 */

?><!DOCTYPE html>
<html <?php language_attributes(); ?>>
<head>
<meta charset="<?php bloginfo( 'charset' ); ?>">
<meta name="viewport" content="width=device-width, initial-scale=1">
<link rel="profile" href="http://gmpg.org/xfn/11">
<?php if ( is_singular() && pings_open( get_queried_object() ) ) : ?>
<link rel="pingback" href="<?php bloginfo( 'pingback_url' ); ?>">
<?php endif; ?>

<?php wp_head(); ?>
</head>

<body <?php body_class(); ?>>
<div id="page" class="site">

	<nav id="site-navigation" class="main-navigation" aria-label="<?php esc_attr_e( 'Primary Menu', 'bloggo' ); ?>">
		<div class="inner">
			<button id="menu-toggle" class="menu-toggle" aria-expanded="false"><span class="icon-menu" aria-hidden="true"></span> <?php esc_html_e( 'Menu', 'bloggo' ); ?></button>
			<div id="menu-container" class="menu-container">
				<?php
				wp_nav_menu( array(
					'theme_location' => 'primary',
					'container'      => false,
					'menu_id'        => 'primary-menu',
					'menu_class'     => 'primary-menu'
				) );
				?>
			</div><!-- .menu-container -->
			<a id="search-show" class="search-show square fill-horizontal" href="#"><span aria-hidden="true" class="fa-search"></span><span class="screen-reader-text"><?php esc_html_e( 'Search', 'bloggo' ); ?></span></a>
		</div><!-- .inner -->
	</nav><!-- .main-navigation -->
	<header id="masthead" class="site-header">
		<div class="inner">
			<div class="site-branding">
				<?php
				if ( has_custom_logo() ) {
					$custom_logo = wp_get_attachment_image_src( get_theme_mod( 'custom_logo' ), 'full' );
					$logo_width = get_theme_mod( 'bloggo_logo_retina' ) ? floor( $custom_logo[1]/2 ) : $custom_logo[1];
					printf( '<a href="%1$s" class="custom-logo-link" rel="home" itemprop="url"><img src="%2$s" width="%3$s" alt="%4$s" /></a>',
						esc_url( home_url( '/' ) ),
						esc_url( $custom_logo[0] ),
						esc_attr( $logo_width ),
						esc_attr( get_bloginfo( 'name', 'display' ) )
					);
				}
				$site_title_link = sprintf( '<a href="%1$s" rel="home">%2$s</a>',
					esc_url( home_url( '/' ) ),
					esc_attr( get_bloginfo( 'name', 'display' ) )
				);
				?>
				<?php if ( is_front_page() && is_home() ) : ?>
				<h1 class="site-title<?php if ( get_theme_mod( 'bloggo_hide_site_title' ) ) echo ' screen-reader-text'; ?>"><?php echo $site_title_link; ?></h1>
				<?php else : ?>
				<p class="site-title<?php if ( get_theme_mod( 'bloggo_hide_site_title' ) ) echo ' screen-reader-text'; ?>"><?php echo $site_title_link; ?></p>
				<?php endif; ?>
				<?php if ( get_bloginfo( 'description' ) ) : ?>
				<p class="site-description<?php if ( get_theme_mod( 'bloggo_hide_tagline' ) ) echo ' screen-reader-text'; ?>"><?php bloginfo( 'description' ); ?></p>
				<?php endif; ?>
			</div><!-- .site-branding -->
		</div><!-- .inner -->
	</header><!-- .site-header -->

	<div id="content" class="site-content">
		<div class="inner">
